; Script to show the Re dependence of Re_{M,crit} for the data
; produced in pencil-nils/isoforce/hyp_norm.
;
;  $Id: Rmcrit.pro,v 1.6 2004/11/08 08:54:17 brandenb Exp $
;
;  mv idl.ps ../fig/Rmcrit.ps
;  mv idl.ps ../../diffrot_freiburg/fig/Rmcrit.ps
;
if !d.name eq 'PS' then begin
  device,xsize=18,ysize=12,yoffset=3
  !p.charthick=5 & !p.thick=5 & !x.thick=5 & !y.thick=5
end
;
siz=1.6
!p.charsize=2.0
!x.title='Pr!dM!n'
!y.title='Re!dM,crit!n'
!x.range=[1e-1,12]
!y.range=[10.,500]
kf=1.5
;
; Some values
;
default,Re_method,8
default,Re_method_smag,8
;
Re=indgen(1000)
;
; Model from nohel_long
;
ReMc=35^(2./3)*Re^(1./3)
;
; The first model from Scekochihin et al. (2004)
;
ReMc_s1=0.2*Re
;
; Data points from nohel_long
;
Pm_nl   = [0.25 ,1.  ,3.  ,10.]
ReMc_nl = [155. ,35. ,22. ,36.]
Re_nl   = ReMc_nl/Pm_nl
;
; Read hyperviscous data set
;
a=rtable('Rmcrit.dat',8,head=1)
nu_hyper   = reform(a(0,*))
ReMc_hyper = reform(a(1,*))
urms       = reform(a(2,*))
orms       = reform(a(3,*))
kNy        = reform(a(4,*))
kpeak      = reform(a(5,*))
nuepso2m   = reform(a(6,*))
nueps2o2m  = reform(a(7,*))
;
; Read Smagorinsky data set
;
a=rtable('Rmcrit_smag.dat',7,head=1)
N_smag          = reform(a(0,*))
ReMc_smag       = reform(a(1,*))
urms_smag       = reform(a(2,*))
orms_smag       = reform(a(3,*))
kNy_smag        = reform(a(4,*))
kpeak_smag      = reform(a(5,*))
nuepso2m_smag   = reform(a(6,*))
;
print,'-------------------------------------------------------'
;
; There are several possible ways of finding the Reynolds number
; of the runs with hyperviscosity: 
;
;
; ------------------METHOD 1------------------------------
; Make connection between nu_hyper and Re (from fig. 5 of nohel_hyper)
; I assume that nu_hyper=1e-9 correspond to the same Reynolds number
; as the 1024^3 simulation, ie approximately 1000. Furthermore I
; assume that we double the Reynolds number as we decrease nu by a
; factor 2^5=32.
; Note that this is NOT the Taylor microscale Reynolds number but the
; Reynolds number based on Re=urms/(kf*nu).
;
if (Re_method eq 1) then begin
    Re_hyper=(1e-9/nu_hyper)^(1./5.)*1000.
endif
;
;
; ------------------METHOD 2------------------------------
;
; Choose an empirical model that fits both the new and old data points
;
if (Re_method eq 2) then begin
    Re_hyper=(1e-9/nu_hyper)^(1./2.)*1000.*3.
endif
;
;
; ------------------METHOD 3------------------------------
;
; Use the standard formulae for Re with the wavenumber k
; based on the Taylor microscale (ie k=orms/(sqrt(5)*urms)),
; and normalized by an empirical factor Re0.
;
if (Re_method eq 3) then begin
    Re0=1e-2
    k=orms/(sqrt(5)*urms)
    Re_hyper=Re0*urms/(nu_hyper*k^5.)
    print,'k=',k
endif
;
;
; ------------------METHOD 4------------------------------
;
; Use the standard formulae for Re with the wavenumber k
; based on k_d=(epsilon/nu_hyper^3)^(1/16) 
; and normalized by an empirical factor Re0.
; (Since all the runs should have the same epsilon we merge it into Re0)
;
if (Re_method eq 4) then begin
    Re0=10.
    epsilon=1.
    k=(epsilon/nu_hyper^3.)^(1./16)
    kappa=k*!pi/kNy
    keff6=kNy^6.*(20.-30.*cos(kappa)+12.*cos(2.*kappa)-2.*cos(3.*kappa))/!pi^6.
    k=keff6^(1./6)
    Re_hyper=Re0*urms/(nu_hyper*k^5.)
    print,'k=',k
endif
;
;
; ------------------METHOD 5------------------------------
;
; Use the standard formulae for Re with the wavenumber k
; based on the peak of the dissipation
; and normalized by an empirical factor Re0.
;
if (Re_method eq 5) then begin
    Re0=10.
    k=kpeak
    Re_hyper=Re0*urms/(nu_hyper*k^5.)
    print,'k=',k
endif
;
;
; ------------------METHOD 6------------------------------
;
; Use Re=Re0*(k_d/k_f)^(3/4) where k_f is the forcing wavenumber 
; and k_d is based on the peak of the dissipation
; and normalized by an empirical factor Re0.
; (see hydro/hyper paper for details)
;
if (Re_method eq 6) then begin
    Re0=9.
    k=kpeak
    Re_hyper=Re0*k^(4./3)
    print,'k=',k
endif
;
; ------------------METHOD 7------------------------------
;
; Use Re=urms/(nuepso2m*kf), where nuepso2m=epsK/o2m, and o2m=orms^2
;
if (Re_method eq 7) then begin
    Re_hyper=urms/(nuepso2m*kf)
endif
;
; ------------------METHOD 8------------------------------
;
; Use Re=urms/(nueps2o2m*kf), where nuepso2m=epsK2/o2m, and o2m=orms^2
;
if (Re_method eq 8) then begin
    Re_hyper=urms/(nueps2o2m*kf)
endif
if (Re_method_smag eq 8) then begin
    Re_smag=urms_smag/(nuepso2m_smag*kf)
endif
;
; Plot the results
;
plot_oo,ReMc/Re,ReMc,background=255,col=1,/nodata
;oplot,ReMc_s1/Re,ReMc_s1,li=2,col=1
oplot,ReMc_nl/Re_nl,ReMc_nl,ps=4,symsize=2,col=1
oplot,ReMc_hyper/Re_hyper,ReMc_hyper,ps=2,symsize=2,col=1
oplot,ReMc_smag/Re_smag,ReMc_smag,ps=5,symsize=2,col=1
;
;  overplot fit from Haugen et al (2004)
;
xx=[.4,3.] & oplot,xx,35/sqrt(xx),col=0
xyouts,.6,20,'35 Pr!s!dM!n!r!u-1/2!n',siz=siz,col=0
;
xx=[.13,.7] & oplot,xx,35/xx,col=0
xyouts,.13,85,'35 Pr!s!dM!n!r!u-1!n',siz=siz,col=0
;
xx=1.5 & dx=0.8
yy=2.5 & dy=-0.15
;legend,xx,dx,10^(yy+dy*1),/log,0,' !635!u2/3!nRe!u1/3!n',col=1
;legend,xx,dx,10^(yy+dy*1),/log,2,' !60.2!nRe!n',col=1

yy=2.8 & dy=-0.17
xx=1.8 & dx=0.
legend,xx,dx,10^(yy+dy*2),/log,0,' normal visc.',ps=4,symsize=siz,col=1
legend,xx,dx,10^(yy+dy*3),/log,0,' hypervisc.',ps=2,symsize=siz,col=1
legend,xx,dx,10^(yy+dy*4),/log,0,' Smagorinsky ',ps=5,symsize=siz,col=1
;
; Some printouts
;
print,'Re_hyper=',Re_hyper
print,'The method used to find Re is method:',Re_method
print,'(Change the value of "Re_method" for different method.)'
print,'-------------------------------------------------------'
;
END
