; Script to show the Re dependence of Re_{M,crit} for the data
; produced in pencil-nils/isoforce/hyp_norm.
;
;  $Id: Rmcrit_Re.pro,v 1.5 2004/12/13 14:13:54 nilshau Exp $
;
;  mv idl.ps ../fig/Rmcrit.ps
;
if !d.name eq 'PS' then begin
  device,xsize=18,ysize=12,yoffset=3
  !p.charthick=3 & !p.thick=3 & !x.thick=3 & !y.thick=3
end
;
!p.charsize=1.6
!x.title='Re!n'
!y.title='Re!dM,crit!n'
!x.range=[0.3,4000]
!y.range=[10.,500]
kf=1.5
;
; Some values
;
default,Re_method,8
default,Re_method_smag,8
;
Re=indgen(4000)
;
; Model from nohel_long
;
ReMc=35^(2./3)*Re^(1./3)
;
; The first model from Scekochihin et al. (2004)
;
ReMc_s1=0.2*Re
;
; Data points from nohel_long
;
Pm_nl   = [0.25  ,1.  ,3.  ,10.]
ReMc_nl = [ 155. ,35. ,22. ,36.]
Re_nl   = ReMc_nl/Pm_nl
;
; Original data points from nohel_long
;
Pm_nlo   = [0.125,0.25,1.  ,3.  ,10.]
ReMc_nlo = [100. ,70. ,35. ,22. ,36.]
Re_nlo   = ReMc_nlo/Pm_nlo
;
; Read hyperviscous data set
;
a=rtable('Rmcrit.dat',8,head=1)
nu_hyper   = reform(a(0,*))
ReMc_hyper = reform(a(1,*))
urms       = reform(a(2,*))
orms       = reform(a(3,*))
kNy        = reform(a(4,*))
kpeak      = reform(a(5,*))
nuepso2m   = reform(a(6,*))
nueps2o2m  = reform(a(7,*))
;
; Read Smagorinsky data set
;
a=rtable('Rmcrit_smag.dat',7,head=1)
N_smag          = reform(a(0,*))
ReMc_smag       = reform(a(1,*))
urms_smag       = reform(a(2,*))
orms_smag       = reform(a(3,*))
kNy_smag        = reform(a(4,*))
kpeak_smag      = reform(a(5,*))
nuepso2m_smag   = reform(a(6,*))
;
print,'-------------------------------------------------------'
;
; There are several possible ways of finding the Reynolds number
; of the runs with hyperviscosity: 
;
;
; ------------------METHOD 1------------------------------
; Make connection between nu_hyper and Re (from fig. 5 of nohel_hyper)
; I assume that nu_hyper=1e-9 correspond to the same Reynolds number
; as the 1024^3 simulation, ie approximately 1000. Furthermore I
; assume that we double the Reynolds number as we decrease nu by a
; factor 2^5=32.
; Note that this is NOT the Taylor microscale Reynolds number but the
; Reynolds number based on Re=urms/(kf*nu).
;
if (Re_method eq 1) then begin
    Re_hyper=(1e-9/nu_hyper)^(1./5.)*1000.
endif
;
;
; ------------------METHOD 2------------------------------
;
; Choose an empirical model that fits both the new and old data points
;
if (Re_method eq 2) then begin
    Re_hyper=(1e-9/nu_hyper)^(1./2.)*1000.*3.
endif
;
;
; ------------------METHOD 3------------------------------
;
; Use the standard formulae for Re with the wavenumber k
; based on the Taylor microscale (ie k=orms/(sqrt(5)*urms)),
; and normalized by an empirical factor Re0.
;
if (Re_method eq 3) then begin
    Re0=1e-2
    k=orms/(sqrt(5)*urms)
    Re_hyper=Re0*urms/(nu_hyper*k^5.)
    print,'k=',k
endif
;
;
; ------------------METHOD 4------------------------------
;
; Use the standard formulae for Re with the wavenumber k
; based on k_d=(epsilon/nu_hyper^3)^(1/16) 
; and normalized by an empirical factor Re0.
; (Since all the runs should have the same epsilon we merge it into Re0)
;
if (Re_method eq 4) then begin
    Re0=10.
    epsilon=1.
    k=(epsilon/nu_hyper^3.)^(1./16)
    kappa=k*!pi/kNy
    keff6=kNy^6.*(20.-30.*cos(kappa)+12.*cos(2.*kappa)-2.*cos(3.*kappa))/!pi^6.
    k=keff6^(1./6)
    Re_hyper=Re0*urms/(nu_hyper*k^5.)
    print,'k=',k
endif
;
;
; ------------------METHOD 5------------------------------
;
; Use the standard formulae for Re with the wavenumber k
; based on the peak of the dissipation
; and normalized by an empirical factor Re0.
;
if (Re_method eq 5) then begin
    Re0=10.
    k=kpeak
    Re_hyper=Re0*urms/(nu_hyper*k^5.)
    print,'k=',k
endif
;
;
; ------------------METHOD 6------------------------------
;
; Use Re=Re0*(k_d/k_f)^(3/4) where k_f is the forcing wavenumber 
; and k_d is based on the peak of the dissipation
; and normalized by an empirical factor Re0.
; (see hydro/hyper paper for details)
;
if (Re_method eq 6) then begin
    Re0=9.
    k=kpeak
    Re_hyper=Re0*k^(4./3)
    print,'k=',k
endif
;
; ------------------METHOD 7------------------------------
;
; Use Re=urms/(nuepso2m*kf), where nuepso2m=epsK/o2m, and o2m=orms^2
;
if (Re_method eq 7) then begin
    Re_hyper=urms/(nuepso2m*kf)
endif
;
; ------------------METHOD 8------------------------------
;
; Use Re=urms/(nueps2o2m*kf), where nuepso2m=epsK2/o2m, and o2m=orms^2
;
if (Re_method eq 8) then begin
    Re_hyper=urms/(nueps2o2m*kf)
endif
if (Re_method_smag eq 8) then begin
    Re_smag=urms_smag/(nuepso2m_smag*kf)
endif
;
; -----------------Alex' data ----------------------------
;
Prm_alex_DNS  = [97.4 ,32.5 ,1.0 , 0.4039, 0.183 ,0.15]
ReMc_alex_DNS = [77.8 ,74.7 ,60. ,110    , 223   , 436]/1.54
Prm_alex_hyper=[0.3506,0.2,0.10]
ReMc_alex_hyper=[114,232.7,461]/1.54
;
Prm_alex_DNS_inter  = [0.15]
ReMc_alex_DNS_inter = [436]/1.54
Prm_alex_hyper_inter=[0.10]
ReMc_alex_hyper_inter=[461]/1.54
;
; Plot the results
;
plot_oo,Re,ReMc,background=255,col=1,/nodata
oplot,Re_nl,ReMc_nl,ps=4,symsize=2,col=1
oplot,Re_nlo,ReMc_nlo,ps=4,symsize=5,col=150
oplot,Re_hyper,ReMc_hyper,ps=2,symsize=2,col=1
oplot,Re_smag,ReMc_smag,ps=5,symsize=2,col=1
oplot,ReMc_alex_DNS/Prm_alex_DNS,ReMc_alex_DNS,ps=4,symsize=2,col=122
oplot,ReMc_alex_hyper/Prm_alex_hyper,ReMc_alex_hyper,ps=2,symsize=2,col=122
oplot,ReMc_alex_DNS_inter/Prm_alex_DNS_inter,ReMc_alex_DNS_inter,ps=4,symsize=2,col=47
oplot,ReMc_alex_hyper_inter/Prm_alex_hyper_inter,ReMc_alex_hyper_inter,ps=2,symsize=2,col=47
;
oplot,Re,ReMc_s1,li=2,col=1
;
xx=1.6 & dx=0.8
yy=2.5 & dy=-0.15
;legend,xx,dx,10^(yy+dy*1),/log,0,' !635!u2/3!nRe!u1/3!n',col=1
;legend,xx,dx,10^(yy+dy*1),/log,2,' !60.2!nRe!n',col=1

yy=2.8 & dy=-0.15
xx=2. & dx=0.
legend,xx,dx,10^(yy+dy*2),/log,0,' normal visc.',ps=4,symsize=2,col=1
legend,xx,dx,10^(yy+dy*3),/log,0,' hyper visc.',ps=2,symsize=2,col=1
legend,xx,dx,10^(yy+dy*4),/log,0,' Smagorinsky ',ps=5,symsize=2,col=1
;
; Some printouts
;
print,'Re_hyper=',Re_hyper
print,'The method used to find Re is method:',Re_method
print,'(Change the value of "Re_method" for different method.)'
print,'-------------------------------------------------------'
;
; Save data as ascii files
;
; DNS
Re1=Re_nl &  Re2=Re1 & Rm1=Re1 & Rm2=Rm1
Re1(0)=250 & Re2(0)=667 & Rm1(0)=63 & Rm2(0)=167 
Re1(1)=26 & Re2(1)=43 & Rm1(1)=26 & Rm2(1)=43 
Re1(2)=5 & Re2(2)=13 & Rm1(2)=15 & Rm2(2)=38 
Re1(3)=2 & Re2(3)=6 & Rm1(3)=20 & Rm2(3)=60 
close,2
dim=(size(Re_nl))[1]
openw,2,'Re_dns.dat'
for i=0,dim-1 do begin
    printf,2,Re_nl(i),ReMc_nl(i),Re1(i),Re2(i),Rm1(i),Rm2(i)
end
close,2
; Hyper

Pm=ReMc_hyper/Re_hyper
Rm1=Pm & Rm2=Rm1
Rm1(0)=29  & Rm2(0)=42
Rm1(1)=43  & Rm2(1)=62
Rm1(2)=62  & Rm2(2)=87
Rm1(3)=87  & Rm2(3)=124
Rm1(4)=90  & Rm2(4)=180
Rm1(5)=173  & Rm2(5)=433
Rm1(6)=289  & Rm2(6)=433
Re1=Rm1/Pm
Re2=Rm2/Pm

close,2
dim=(size(Re_hyper))[1]
openw,2,'Re_hyper.dat'
for i=0,dim-1 do begin
    printf,2,Re_hyper(i),ReMc_hyper(i),Re1(i),Re2(i),Rm1(i),Rm2(i)
end
close,2
; Smagorinsky
Pm=ReMc_smag/Re_smag
Rm1=Pm & Rm2=Rm1
Rm1(0)=49  & Rm2(0)=88 
Rm1(1)=73  & Rm2(1)=147
Rm1(2)=123 & Rm2(2)=170
Rm1(3)=144 & Rm2(3)=298
Re1=Rm1/Pm
Re2=Rm2/Pm

close,2
dim=(size(Re_smag))[1]
openw,2,'Re_smag.dat'
for i=0,dim-1 do begin
    printf,2,Re_smag(i),ReMc_smag(i),Re1(i),Re2(i),Rm1(i),Rm2(i)
end
close,2

END
